==> haskell-data-serializer-0.3.4-67-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-data-serializer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-serializer
version: 0.3.4
id: data-serializer-0.3.4-1KaLp0iasZn57F8UZkYPvY
key: data-serializer-0.3.4-1KaLp0iasZn57F8UZkYPvY
license: BSD-3-Clause
copyright: 2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-serializer
synopsis: Common API for serialization libraries
description:
    This package provides a common API for serialization libraries like
    <http://hackage.haskell.org/package/binary binary> and
    <http://hackage.haskell.org/package/cereal cereal>.
category: Data
abi: 133106c96f48a1259bf85006c83383f0
exposed: True
exposed-modules:
    Data.Deserializer Data.Serializer
import-dirs: /usr/lib/ghc-8.6.5/site-local/data-serializer-0.3.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/data-serializer-0.3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/data-serializer-0.3.4
hs-libraries: HSdata-serializer-0.3.4-1KaLp0iasZn57F8UZkYPvY
depends:
    base-4.12.0.0 binary-0.8.6.0 bytestring-0.10.8.2
    cereal-0.5.8.1-7AyRb7vLva5K85rZXh3kQh
    data-endian-0.1.1-8eI15msEBjH5vqdbWN68zz
    parsers-0.12.10-GdosIGswbE2Fya2n6eMQtp
    split-0.2.3.3-4dhvbosBVIlDAhhwnzSbSM
haddock-interfaces: /usr/share/doc/haskell-data-serializer/html/data-serializer.haddock
haddock-html: /usr/share/doc/haskell-data-serializer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-serializer-0.3.4-68-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-data-serializer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-serializer
version: 0.3.4
id: data-serializer-0.3.4-1q9XuapsJGWHSbSwawZkDX
key: data-serializer-0.3.4-1q9XuapsJGWHSbSwawZkDX
license: BSD-3-Clause
copyright: 2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-serializer
synopsis: Common API for serialization libraries
description:
    This package provides a common API for serialization libraries like
    <http://hackage.haskell.org/package/binary binary> and
    <http://hackage.haskell.org/package/cereal cereal>.
category: Data
abi: 49c72d25dd5f1ecd2b5883ce12809ab6
exposed: True
exposed-modules:
    Data.Deserializer Data.Serializer
import-dirs: /usr/lib/ghc-8.6.5/site-local/data-serializer-0.3.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/data-serializer-0.3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/data-serializer-0.3.4
hs-libraries: HSdata-serializer-0.3.4-1q9XuapsJGWHSbSwawZkDX
depends:
    base-4.12.0.0 binary-0.8.6.0 bytestring-0.10.8.2
    cereal-0.5.8.1-7AyRb7vLva5K85rZXh3kQh
    data-endian-0.1.1-8eI15msEBjH5vqdbWN68zz
    parsers-0.12.10-CPtsIzB5IA3A9mhcixCp52
    split-0.2.3.3-4dhvbosBVIlDAhhwnzSbSM
haddock-interfaces: /usr/share/doc/haskell-data-serializer/html/data-serializer.haddock
haddock-html: /usr/share/doc/haskell-data-serializer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
